@@ -1,6 +1,15 @@
+from __future__ import annotations
+
+from typing import TYPE_CHECKING
+
 from dateutil.parser import isoparse
 
-from hcloud.core.domain import BaseDomain
+from ..core import BaseDomain
+
+if TYPE_CHECKING:
+    from ..actions import BoundAction
+    from ..servers import BoundServer
+    from .client import BoundNetwork
 
 
 class Network(BaseDomain):
@@ -16,6 +25,8 @@ class Network(BaseDomain):
            Subnets allocated in this network
     :param routes: List[:class:`NetworkRoute <hcloud.networks.domain.NetworkRoute>`]
            Routes set in this network
+    :param expose_routes_to_vswitch: bool
+           Indicates if the routes from this network should be exposed to the vSwitch connection.
     :param servers: List[:class:`BoundServer <hcloud.servers.client.BoundServer>`]
            Servers attached to this network
     :param protection: dict
@@ -30,6 +41,7 @@ class Network(BaseDomain):
         "ip_range",
         "subnets",
         "routes",
+        "expose_routes_to_vswitch",
         "servers",
         "protection",
         "labels",
@@ -38,15 +50,16 @@ class Network(BaseDomain):
 
     def __init__(
         self,
-        id,
-        name=None,
-        created=None,
-        ip_range=None,
-        subnets=None,
-        routes=None,
-        servers=None,
-        protection=None,
-        labels=None,
+        id: int,
+        name: str | None = None,
+        created: str | None = None,
+        ip_range: str | None = None,
+        subnets: list[NetworkSubnet] | None = None,
+        routes: list[NetworkRoute] | None = None,
+        expose_routes_to_vswitch: bool | None = None,
+        servers: list[BoundServer] | None = None,
+        protection: dict | None = None,
+        labels: dict[str, str] | None = None,
     ):
         self.id = id
         self.name = name
@@ -54,6 +67,7 @@ class Network(BaseDomain):
         self.ip_range = ip_range
         self.subnets = subnets
         self.routes = routes
+        self.expose_routes_to_vswitch = expose_routes_to_vswitch
         self.servers = servers
         self.protection = protection
         self.labels = labels
@@ -83,7 +97,12 @@ class NetworkSubnet(BaseDomain):
     __slots__ = ("type", "ip_range", "network_zone", "gateway", "vswitch_id")
 
     def __init__(
-        self, ip_range, type=None, network_zone=None, gateway=None, vswitch_id=None
+        self,
+        ip_range: str,
+        type: str | None = None,
+        network_zone: str | None = None,
+        gateway: str | None = None,
+        vswitch_id: int | None = None,
     ):
         self.type = type
         self.ip_range = ip_range
@@ -103,7 +122,7 @@ class NetworkRoute(BaseDomain):
 
     __slots__ = ("destination", "gateway")
 
-    def __init__(self, destination, gateway):
+    def __init__(self, destination: str, gateway: str):
         self.destination = destination
         self.gateway = gateway
 
@@ -121,8 +140,8 @@ class CreateNetworkResponse(BaseDomain):
 
     def __init__(
         self,
-        network,  # type: BoundNetwork
-        action,  # type: BoundAction
+        network: BoundNetwork,
+        action: BoundAction,
     ):
         self.network = network
         self.action = action
